// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package datasync provides the client and types for making API
// requests to AWS DataSync.
//
// AWS DataSync is a managed data transfer service that makes it simpler for
// you to automate moving data between on-premises storage and Amazon Simple
// Storage Service (Amazon S3) or Amazon Elastic File System (Amazon EFS).
//
// This API interface reference for AWS DataSync contains documentation for
// a programming interface that you can use to manage AWS DataSync.
//
// See https://docs.aws.amazon.com/goto/WebAPI/datasync-2018-11-09 for more information on this service.
//
// See datasync package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/datasync/
//
// Using the Client
//
// To contact AWS DataSync with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS DataSync client DataSync for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/datasync/#New
package datasync
