// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package iotjobsdataplaneiface provides an interface to enable mocking the AWS IoT Jobs Data Plane service client
// for testing your code.
//
// It is important to note that this interface will have breaking changes
// when the service model is updated and adds new API operations, paginators,
// and waiters.
package iotjobsdataplaneiface

import (
	"github.com/aws/aws-sdk-go/aws"
	"github.com/aws/aws-sdk-go/aws/request"
	"github.com/aws/aws-sdk-go/service/iotjobsdataplane"
)

// IoTJobsDataPlaneAPI provides an interface to enable mocking the
// iotjobsdataplane.IoTJobsDataPlane service client's API operation,
// paginators, and waiters. This make unit testing your code that calls out
// to the SDK's service client's calls easier.
//
// The best way to use this interface is so the SDK's service client's calls
// can be stubbed out for unit testing your code with the SDK without needing
// to inject custom request handlers into the SDK's request pipeline.
//
//    // myFunc uses an SDK service client to make a request to
//    // AWS IoT Jobs Data Plane.
//    func myFunc(svc iotjobsdataplaneiface.IoTJobsDataPlaneAPI) bool {
//        // Make svc.DescribeJobExecution request
//    }
//
//    func main() {
//        sess := session.New()
//        svc := iotjobsdataplane.New(sess)
//
//        myFunc(svc)
//    }
//
// In your _test.go file:
//
//    // Define a mock struct to be used in your unit tests of myFunc.
//    type mockIoTJobsDataPlaneClient struct {
//        iotjobsdataplaneiface.IoTJobsDataPlaneAPI
//    }
//    func (m *mockIoTJobsDataPlaneClient) DescribeJobExecution(input *iotjobsdataplane.DescribeJobExecutionInput) (*iotjobsdataplane.DescribeJobExecutionOutput, error) {
//        // mock response/functionality
//    }
//
//    func TestMyFunc(t *testing.T) {
//        // Setup Test
//        mockSvc := &mockIoTJobsDataPlaneClient{}
//
//        myfunc(mockSvc)
//
//        // Verify myFunc's functionality
//    }
//
// It is important to note that this interface will have breaking changes
// when the service model is updated and adds new API operations, paginators,
// and waiters. Its suggested to use the pattern above for testing, or using
// tooling to generate mocks to satisfy the interfaces.
type IoTJobsDataPlaneAPI interface {
	DescribeJobExecution(*iotjobsdataplane.DescribeJobExecutionInput) (*iotjobsdataplane.DescribeJobExecutionOutput, error)
	DescribeJobExecutionWithContext(aws.Context, *iotjobsdataplane.DescribeJobExecutionInput, ...request.Option) (*iotjobsdataplane.DescribeJobExecutionOutput, error)
	DescribeJobExecutionRequest(*iotjobsdataplane.DescribeJobExecutionInput) (*request.Request, *iotjobsdataplane.DescribeJobExecutionOutput)

	GetPendingJobExecutions(*iotjobsdataplane.GetPendingJobExecutionsInput) (*iotjobsdataplane.GetPendingJobExecutionsOutput, error)
	GetPendingJobExecutionsWithContext(aws.Context, *iotjobsdataplane.GetPendingJobExecutionsInput, ...request.Option) (*iotjobsdataplane.GetPendingJobExecutionsOutput, error)
	GetPendingJobExecutionsRequest(*iotjobsdataplane.GetPendingJobExecutionsInput) (*request.Request, *iotjobsdataplane.GetPendingJobExecutionsOutput)

	StartNextPendingJobExecution(*iotjobsdataplane.StartNextPendingJobExecutionInput) (*iotjobsdataplane.StartNextPendingJobExecutionOutput, error)
	StartNextPendingJobExecutionWithContext(aws.Context, *iotjobsdataplane.StartNextPendingJobExecutionInput, ...request.Option) (*iotjobsdataplane.StartNextPendingJobExecutionOutput, error)
	StartNextPendingJobExecutionRequest(*iotjobsdataplane.StartNextPendingJobExecutionInput) (*request.Request, *iotjobsdataplane.StartNextPendingJobExecutionOutput)

	UpdateJobExecution(*iotjobsdataplane.UpdateJobExecutionInput) (*iotjobsdataplane.UpdateJobExecutionOutput, error)
	UpdateJobExecutionWithContext(aws.Context, *iotjobsdataplane.UpdateJobExecutionInput, ...request.Option) (*iotjobsdataplane.UpdateJobExecutionOutput, error)
	UpdateJobExecutionRequest(*iotjobsdataplane.UpdateJobExecutionInput) (*request.Request, *iotjobsdataplane.UpdateJobExecutionOutput)
}

var _ IoTJobsDataPlaneAPI = (*iotjobsdataplane.IoTJobsDataPlane)(nil)
