// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package waf provides the client and types for making API
// requests to AWS WAF.
//
//
// This is AWS WAF Classic documentation. For more information, see AWS WAF
// Classic (https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)
// in the developer guide.
//
// For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS
// WAF Developer Guide (https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html).
// With the latest version, AWS WAF has a single set of endpoints for regional
// and global use.
//
// This is the AWS WAF Classic API Reference for using AWS WAF Classic with
// Amazon CloudFront. The AWS WAF Classic actions and data types listed in the
// reference are available for protecting Amazon CloudFront distributions. You
// can use these actions and data types via the endpoint waf.amazonaws.com.
// This guide is for developers who need detailed information about the AWS
// WAF Classic API actions, data types, and errors. For detailed information
// about AWS WAF Classic features and an overview of how to use the AWS WAF
// Classic API, see the AWS WAF Classic (https://docs.aws.amazon.com/waf/latest/developerguide/classic-waf-chapter.html)
// in the developer guide.
//
// See https://docs.aws.amazon.com/goto/WebAPI/waf-2015-08-24 for more information on this service.
//
// See waf package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/waf/
//
// Using the Client
//
// To contact AWS WAF with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS WAF client WAF for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/waf/#New
package waf
