// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package iotdeviceadvisor provides the client and types for making API
// requests to AWS IoT Core Device Advisor.
//
// AWS IoT Core Device Advisor is a cloud-based, fully managed test capability
// for validating IoT devices during device software development. Device Advisor
// provides pre-built tests that you can use to validate IoT devices for reliable
// and secure connectivity with AWS IoT Core before deploying devices to production.
// By using Device Advisor, you can confirm that your devices can connect to
// AWS IoT Core, follow security best practices and, if applicable, receive
// software updates from IoT Device Management. You can also download signed
// qualification reports to submit to the AWS Partner Network to get your device
// qualified for the AWS Partner Device Catalog without the need to send your
// device in and wait for it to be tested.
//
// See https://docs.aws.amazon.com/goto/WebAPI/iotdeviceadvisor-2020-09-18 for more information on this service.
//
// See iotdeviceadvisor package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/iotdeviceadvisor/
//
// Using the Client
//
// To contact AWS IoT Core Device Advisor with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS IoT Core Device Advisor client IoTDeviceAdvisor for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/iotdeviceadvisor/#New
package iotdeviceadvisor
