// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package autoscalingplans provides the client and types for making API
// requests to AWS Auto Scaling Plans.
//
// Use AWS Auto Scaling to quickly discover all the scalable AWS resources for
// your application and configure dynamic scaling and predictive scaling for
// your resources using scaling plans. Use this service in conjunction with
// the Amazon EC2 Auto Scaling, Application Auto Scaling, Amazon CloudWatch,
// and AWS CloudFormation services.
//
// Currently, predictive scaling is only available for Amazon EC2 Auto Scaling
// groups.
//
// For more information about AWS Auto Scaling, including information about
// granting IAM users required permissions for AWS Auto Scaling actions, see
// the AWS Auto Scaling User Guide (https://docs.aws.amazon.com/autoscaling/plans/userguide/what-is-aws-auto-scaling.html).
//
// See https://docs.aws.amazon.com/goto/WebAPI/autoscaling-plans-2018-01-06 for more information on this service.
//
// See autoscalingplans package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/autoscalingplans/
//
// Using the Client
//
// To contact AWS Auto Scaling Plans with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Auto Scaling Plans client AutoScalingPlans for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/autoscalingplans/#New
package autoscalingplans
