// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package appstream provides the client and types for making API
// requests to Amazon AppStream.
//
// This is the Amazon AppStream 2.0 API Reference. This documentation provides
// descriptions and syntax for each of the actions and data types in AppStream
// 2.0. AppStream 2.0 is a fully managed, secure application streaming service
// that lets you stream desktop applications to users without rewriting applications.
// AppStream 2.0 manages the AWS resources that are required to host and run
// your applications, scales automatically, and provides access to your users
// on demand.
//
// You can call the AppStream 2.0 API operations by using an interface VPC endpoint
// (interface endpoint). For more information, see Access AppStream 2.0 API
// Operations and CLI Commands Through an Interface VPC Endpoint (https://docs.aws.amazon.com/appstream2/latest/developerguide/access-api-cli-through-interface-vpc-endpoint.html)
// in the Amazon AppStream 2.0 Administration Guide.
//
// To learn more about AppStream 2.0, see the following resources:
//
//    * Amazon AppStream 2.0 product page (http://aws.amazon.com/appstream2)
//
//    * Amazon AppStream 2.0 documentation (http://aws.amazon.com/documentation/appstream2)
//
// See https://docs.aws.amazon.com/goto/WebAPI/appstream-2016-12-01 for more information on this service.
//
// See appstream package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/appstream/
//
// Using the Client
//
// To contact Amazon AppStream with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon AppStream client AppStream for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/appstream/#New
package appstream
