// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package accessanalyzer provides the client and types for making API
// requests to Access Analyzer.
//
// AWS IAM Access Analyzer helps identify potential resource-access risks by
// enabling you to identify any policies that grant access to an external principal.
// It does this by using logic-based reasoning to analyze resource-based policies
// in your AWS environment. An external principal can be another AWS account,
// a root user, an IAM user or role, a federated user, an AWS service, or an
// anonymous user. This guide describes the AWS IAM Access Analyzer operations
// that you can call programmatically. For general information about Access
// Analyzer, see AWS IAM Access Analyzer (https://docs.aws.amazon.com/IAM/latest/UserGuide/what-is-access-analyzer.html)
// in the IAM User Guide.
//
// To start using Access Analyzer, you first need to create an analyzer.
//
// See https://docs.aws.amazon.com/goto/WebAPI/accessanalyzer-2019-11-01 for more information on this service.
//
// See accessanalyzer package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/accessanalyzer/
//
// Using the Client
//
// To contact Access Analyzer with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Access Analyzer client AccessAnalyzer for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/accessanalyzer/#New
package accessanalyzer
