// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package marketplacecatalog

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeAccessDeniedException for service response error code
	// "AccessDeniedException".
	//
	// Access is denied.
	ErrCodeAccessDeniedException = "AccessDeniedException"

	// ErrCodeInternalServiceException for service response error code
	// "InternalServiceException".
	//
	// There was an internal service exception.
	ErrCodeInternalServiceException = "InternalServiceException"

	// ErrCodeResourceInUseException for service response error code
	// "ResourceInUseException".
	//
	// The resource is currently in use.
	ErrCodeResourceInUseException = "ResourceInUseException"

	// ErrCodeResourceNotFoundException for service response error code
	// "ResourceNotFoundException".
	//
	// The specified resource wasn't found.
	ErrCodeResourceNotFoundException = "ResourceNotFoundException"

	// ErrCodeResourceNotSupportedException for service response error code
	// "ResourceNotSupportedException".
	//
	// Currently, the specified resource is not supported.
	ErrCodeResourceNotSupportedException = "ResourceNotSupportedException"

	// ErrCodeServiceQuotaExceededException for service response error code
	// "ServiceQuotaExceededException".
	//
	// The maximum number of open requests per account has been exceeded.
	ErrCodeServiceQuotaExceededException = "ServiceQuotaExceededException"

	// ErrCodeThrottlingException for service response error code
	// "ThrottlingException".
	//
	// Too many requests.
	ErrCodeThrottlingException = "ThrottlingException"

	// ErrCodeValidationException for service response error code
	// "ValidationException".
	//
	// An error occurred during validation.
	ErrCodeValidationException = "ValidationException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"AccessDeniedException":         newErrorAccessDeniedException,
	"InternalServiceException":      newErrorInternalServiceException,
	"ResourceInUseException":        newErrorResourceInUseException,
	"ResourceNotFoundException":     newErrorResourceNotFoundException,
	"ResourceNotSupportedException": newErrorResourceNotSupportedException,
	"ServiceQuotaExceededException": newErrorServiceQuotaExceededException,
	"ThrottlingException":           newErrorThrottlingException,
	"ValidationException":           newErrorValidationException,
}
