// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package appflow provides the client and types for making API
// requests to Amazon Appflow.
//
// Welcome to the Amazon AppFlow API reference. This guide is for developers
// who need detailed information about the Amazon AppFlow API operations, data
// types, and errors.
//
// Amazon AppFlow is a fully managed integration service that enables you to
// securely transfer data between software as a service (SaaS) applications
// like Salesforce, Marketo, Slack, and ServiceNow, and AWS services like Amazon
// S3 and Amazon Redshift.
//
// Use the following links to get started on the Amazon AppFlow API:
//
//    * Actions (https://docs.aws.amazon.com/appflow/1.0/APIReference/API_Operations.html):
//    An alphabetical list of all Amazon AppFlow API operations.
//
//    * Data types (https://docs.aws.amazon.com/appflow/1.0/APIReference/API_Types.html):
//    An alphabetical list of all Amazon AppFlow data types.
//
//    * Common parameters (https://docs.aws.amazon.com/appflow/1.0/APIReference/CommonParameters.html):
//    Parameters that all Query operations can use.
//
//    * Common errors (https://docs.aws.amazon.com/appflow/1.0/APIReference/CommonErrors.html):
//    Client and server errors that all operations can return.
//
// If you're new to Amazon AppFlow, we recommend that you review the Amazon
// AppFlow User Guide (https://docs.aws.amazon.com/appflow/latest/userguide/what-is-appflow.html).
//
// Amazon AppFlow API users can use vendor-specific mechanisms for OAuth, and
// include applicable OAuth attributes (such as auth-code and redirecturi) with
// the connector-specific ConnectorProfileProperties when creating a new connector
// profile using Amazon AppFlow API operations. For example, Salesforce users
// can refer to the Authorize Apps with OAuth (https://help.salesforce.com/articleView?id=remoteaccess_authenticate.htm)
// documentation.
//
// See https://docs.aws.amazon.com/goto/WebAPI/appflow-2020-08-23 for more information on this service.
//
// See appflow package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/appflow/
//
// Using the Client
//
// To contact Amazon Appflow with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Appflow client Appflow for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/appflow/#New
package appflow
