// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package batch provides the client and types for making API
// requests to AWS Batch.
//
// Using AWS Batch, you can run batch computing workloads on the AWS Cloud.
// Batch computing is a common means for developers, scientists, and engineers
// to access large amounts of compute resources. AWS Batch utilizes the advantages
// of this computing workload to remove the undifferentiated heavy lifting of
// configuring and managing required infrastructure, while also adopting a familiar
// batch computing software approach. Given these advantages, AWS Batch can
// help you to efficiently provision resources in response to jobs submitted,
// thus effectively helping to eliminate capacity constraints, reduce compute
// costs, and deliver your results more quickly.
//
// As a fully managed service, AWS Batch can run batch computing workloads of
// any scale. AWS Batch automatically provisions compute resources and optimizes
// workload distribution based on the quantity and scale of your specific workloads.
// With AWS Batch, there's no need to install or manage batch computing software.
// This means that you can focus your time and energy on analyzing results and
// solving your specific problems.
//
// See https://docs.aws.amazon.com/goto/WebAPI/batch-2016-08-10 for more information on this service.
//
// See batch package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/batch/
//
// Using the Client
//
// To contact AWS Batch with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Batch client Batch for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/batch/#New
package batch
