// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package databasemigrationservice provides the client and types for making API
// requests to AWS Database Migration Service.
//
// AWS Database Migration Service (AWS DMS) can migrate your data to and from
// the most widely used commercial and open-source databases such as Oracle,
// PostgreSQL, Microsoft SQL Server, Amazon Redshift, MariaDB, Amazon Aurora,
// MySQL, and SAP Adaptive Server Enterprise (ASE). The service supports homogeneous
// migrations such as Oracle to Oracle, as well as heterogeneous migrations
// between different database platforms, such as Oracle to MySQL or SQL Server
// to PostgreSQL.
//
// For more information about AWS DMS, see What Is AWS Database Migration Service?
// (https://docs.aws.amazon.com/dms/latest/userguide/Welcome.html) in the AWS
// Database Migration User Guide.
//
// See https://docs.aws.amazon.com/goto/WebAPI/dms-2016-01-01 for more information on this service.
//
// See databasemigrationservice package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/databasemigrationservice/
//
// Using the Client
//
// To contact AWS Database Migration Service with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Database Migration Service client DatabaseMigrationService for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/databasemigrationservice/#New
package databasemigrationservice
