// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package clouddirectory provides the client and types for making API
// requests to Amazon CloudDirectory.
//
// Amazon Cloud Directory is a component of the AWS Directory Service that simplifies
// the development and management of cloud-scale web, mobile, and IoT applications.
// This guide describes the Cloud Directory operations that you can call programmatically
// and includes detailed information on data types and errors. For information
// about Cloud Directory features, see AWS Directory Service (https://aws.amazon.com/directoryservice/)
// and the Amazon Cloud Directory Developer Guide (https://docs.aws.amazon.com/clouddirectory/latest/developerguide/what_is_cloud_directory.html).
//
// See https://docs.aws.amazon.com/goto/WebAPI/clouddirectory-2017-01-11 for more information on this service.
//
// See clouddirectory package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/clouddirectory/
//
// Using the Client
//
// To contact Amazon CloudDirectory with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon CloudDirectory client CloudDirectory for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/clouddirectory/#New
package clouddirectory
