// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package eventbridge provides the client and types for making API
// requests to Amazon EventBridge.
//
// Amazon EventBridge helps you to respond to state changes in your AWS resources.
// When your resources change state, they automatically send events into an
// event stream. You can create rules that match selected events in the stream
// and route them to targets to take action. You can also use rules to take
// action on a predetermined schedule. For example, you can configure rules
// to:
//
//    * Automatically invoke an AWS Lambda function to update DNS entries when
//    an event notifies you that Amazon EC2 instance enters the running state.
//
//    * Direct specific API records from AWS CloudTrail to an Amazon Kinesis
//    data stream for detailed analysis of potential security or availability
//    risks.
//
//    * Periodically invoke a built-in target to create a snapshot of an Amazon
//    EBS volume.
//
// For more information about the features of Amazon EventBridge, see the Amazon
// EventBridge User Guide (https://docs.aws.amazon.com/eventbridge/latest/userguide).
//
// See https://docs.aws.amazon.com/goto/WebAPI/eventbridge-2015-10-07 for more information on this service.
//
// See eventbridge package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/eventbridge/
//
// Using the Client
//
// To contact Amazon EventBridge with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon EventBridge client EventBridge for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/eventbridge/#New
package eventbridge
