// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package apigateway provides the client and types for making API
// requests to Amazon API Gateway.
//
// Amazon API Gateway helps developers deliver robust, secure, and scalable
// mobile and web application back ends. API Gateway allows developers to securely
// connect mobile and web applications to APIs that run on AWS Lambda, Amazon
// EC2, or other publicly addressable web services that are hosted outside of
// AWS.
//
// See apigateway package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/apigateway/
//
// Using the Client
//
// To contact Amazon API Gateway with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon API Gateway client APIGateway for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/apigateway/#New
package apigateway
