// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package lexmodelbuildingservice provides the client and types for making API
// requests to Amazon Lex Model Building Service.
//
// Amazon Lex is an AWS service for building conversational voice and text interfaces.
// Use these actions to create, update, and delete conversational bots for new
// and existing client applications.
//
// See https://docs.aws.amazon.com/goto/WebAPI/lex-models-2017-04-19 for more information on this service.
//
// See lexmodelbuildingservice package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/lexmodelbuildingservice/
//
// Using the Client
//
// To contact Amazon Lex Model Building Service with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Lex Model Building Service client LexModelBuildingService for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/lexmodelbuildingservice/#New
package lexmodelbuildingservice
