// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package acmpca provides the client and types for making API
// requests to AWS Certificate Manager Private Certificate Authority.
//
//
// This is the ACM Private CA API Reference. It provides descriptions, syntax,
// and usage examples for each of the actions and data types involved in creating
// and managing private certificate authorities (CA) for your organization.
//
// The documentation for each action shows the Query API request parameters
// and the XML response. Alternatively, you can use one of the AWS SDKs to access
// an API that's tailored to the programming language or platform that you're
// using. For more information, see AWS SDKs (https://aws.amazon.com/tools/#SDKs).
//
// Each ACM Private CA API action has a quota that determines the number of
// times the action can be called per second. For more information, see API
// Rate Quotas in ACM Private CA (https://docs.aws.amazon.com/acm-pca/latest/userguide/PcaLimits.html#PcaLimits-api)
// in the ACM Private CA user guide.
//
// See https://docs.aws.amazon.com/goto/WebAPI/acm-pca-2017-08-22 for more information on this service.
//
// See acmpca package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/acmpca/
//
// Using the Client
//
// To contact AWS Certificate Manager Private Certificate Authority with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Certificate Manager Private Certificate Authority client ACMPCA for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/acmpca/#New
package acmpca
