// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package migrationhub provides the client and types for making API
// requests to AWS Migration Hub.
//
// The AWS Migration Hub API methods help to obtain server and application migration
// status and integrate your resource-specific migration tool by providing a
// programmatic interface to Migration Hub.
//
// Remember that you must set your AWS Migration Hub home region before you
// call any of these APIs, or a HomeRegionNotSetException error will be returned.
// Also, you must make the API calls while in your home region.
//
// See https://docs.aws.amazon.com/goto/WebAPI/AWSMigrationHub-2017-05-31 for more information on this service.
//
// See migrationhub package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/migrationhub/
//
// Using the Client
//
// To contact AWS Migration Hub with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Migration Hub client MigrationHub for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/migrationhub/#New
package migrationhub
