// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package devicefarm provides the client and types for making API
// requests to AWS Device Farm.
//
// Welcome to the AWS Device Farm API documentation, which contains APIs for:
//
//    * Testing on desktop browsers Device Farm makes it possible for you to
//    test your web applications on desktop browsers using Selenium. The APIs
//    for desktop browser testing contain TestGrid in their names. For more
//    information, see Testing Web Applications on Selenium with Device Farm
//    (https://docs.aws.amazon.com/devicefarm/latest/testgrid/).
//
//    * Testing on real mobile devices Device Farm makes it possible for you
//    to test apps on physical phones, tablets, and other devices in the cloud.
//    For more information, see the Device Farm Developer Guide (https://docs.aws.amazon.com/devicefarm/latest/developerguide/).
//
// See https://docs.aws.amazon.com/goto/WebAPI/devicefarm-2015-06-23 for more information on this service.
//
// See devicefarm package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/devicefarm/
//
// Using the Client
//
// To contact AWS Device Farm with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Device Farm client DeviceFarm for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/devicefarm/#New
package devicefarm
