// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package mq provides the client and types for making API
// requests to AmazonMQ.
//
// Amazon MQ is a managed message broker service for Apache ActiveMQ and RabbitMQ
// that makes it easy to set up and operate message brokers in the cloud. A
// message broker allows software applications and components to communicate
// using various programming languages, operating systems, and formal messaging
// protocols.
//
// See https://docs.aws.amazon.com/goto/WebAPI/mq-2017-11-27 for more information on this service.
//
// See mq package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/mq/
//
// Using the Client
//
// To contact AmazonMQ with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AmazonMQ client MQ for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/mq/#New
package mq
