// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package redshiftdataapiservice

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeExecuteStatementException for service response error code
	// "ExecuteStatementException".
	//
	// The SQL statement encountered an environmental error while running.
	ErrCodeExecuteStatementException = "ExecuteStatementException"

	// ErrCodeInternalServerException for service response error code
	// "InternalServerException".
	//
	// The Amazon Redshift Data API operation failed due to invalid input.
	ErrCodeInternalServerException = "InternalServerException"

	// ErrCodeResourceNotFoundException for service response error code
	// "ResourceNotFoundException".
	//
	// The Amazon Redshift Data API operation failed due to a missing resource.
	ErrCodeResourceNotFoundException = "ResourceNotFoundException"

	// ErrCodeValidationException for service response error code
	// "ValidationException".
	//
	// The Amazon Redshift Data API operation failed due to invalid input.
	ErrCodeValidationException = "ValidationException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"ExecuteStatementException": newErrorExecuteStatementException,
	"InternalServerException":   newErrorInternalServerException,
	"ResourceNotFoundException": newErrorResourceNotFoundException,
	"ValidationException":       newErrorValidationException,
}
