// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package kinesisanalytics provides the client and types for making API
// requests to Amazon Kinesis Analytics.
//
// Overview
//
// This documentation is for version 1 of the Amazon Kinesis Data Analytics
// API, which only supports SQL applications. Version 2 of the API supports
// SQL and Java applications. For more information about version 2, see Amazon
// Kinesis Data Analytics API V2 Documentation (/kinesisanalytics/latest/apiv2/Welcome.html).
//
// This is the Amazon Kinesis Analytics v1 API Reference. The Amazon Kinesis
// Analytics Developer Guide provides additional information.
//
// See https://docs.aws.amazon.com/goto/WebAPI/kinesisanalytics-2015-08-14 for more information on this service.
//
// See kinesisanalytics package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/kinesisanalytics/
//
// Using the Client
//
// To contact Amazon Kinesis Analytics with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Kinesis Analytics client KinesisAnalytics for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/kinesisanalytics/#New
package kinesisanalytics
