// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package ioteventsdata provides the client and types for making API
// requests to AWS IoT Events Data.
//
// AWS IoT Events monitors your equipment or device fleets for failures or changes
// in operation, and triggers actions when such events occur. AWS IoT Events
// Data API commands enable you to send inputs to detectors, list detectors,
// and view or update a detector's status.
//
// See https://docs.aws.amazon.com/goto/WebAPI/iotevents-data-2018-10-23 for more information on this service.
//
// See ioteventsdata package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/ioteventsdata/
//
// Using the Client
//
// To contact AWS IoT Events Data with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS IoT Events Data client IoTEventsData for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/ioteventsdata/#New
package ioteventsdata
