// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package connectcontactlens provides the client and types for making API
// requests to Amazon Connect Contact Lens.
//
// Contact Lens for Amazon Connect enables you to analyze conversations between
// customer and agents, by using speech transcription, natural language processing,
// and intelligent search capabilities. It performs sentiment analysis, detects
// issues, and enables you to automatically categorize contacts.
//
// Contact Lens for Amazon Connect provides both real-time and post-call analytics
// of customer-agent conversations. For more information, see Analyze conversations
// using Contact Lens (https://docs.aws.amazon.com/connect/latest/adminguide/analyze-conversations.html)
// in the Amazon Connect Administrator Guide.
//
// See https://docs.aws.amazon.com/goto/WebAPI/connect-contact-lens-2020-08-21 for more information on this service.
//
// See connectcontactlens package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/connectcontactlens/
//
// Using the Client
//
// To contact Amazon Connect Contact Lens with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Connect Contact Lens client ConnectContactLens for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/connectcontactlens/#New
package connectcontactlens
