// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package lookoutforvision provides the client and types for making API
// requests to Amazon Lookout for Vision.
//
// This is the Amazon Lookout for Vision API Reference. It provides descriptions
// of actions, data types, common parameters, and common errors.
//
// Amazon Lookout for Vision enables you to find visual defects in industrial
// products, accurately and at scale. It uses computer vision to identify missing
// components in an industrial product, damage to vehicles or structures, irregularities
// in production lines, and even minuscule defects in silicon wafers — or
// any other physical item where quality is important such as a missing capacitor
// on printed circuit boards.
//
// See https://docs.aws.amazon.com/goto/WebAPI/lookoutvision-2020-11-20 for more information on this service.
//
// See lookoutforvision package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/lookoutforvision/
//
// Using the Client
//
// To contact Amazon Lookout for Vision with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Lookout for Vision client LookoutForVision for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/lookoutforvision/#New
package lookoutforvision
