// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package alexaforbusiness

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeAlreadyExistsException for service response error code
	// "AlreadyExistsException".
	//
	// The resource being created already exists.
	ErrCodeAlreadyExistsException = "AlreadyExistsException"

	// ErrCodeConcurrentModificationException for service response error code
	// "ConcurrentModificationException".
	//
	// There is a concurrent modification of resources.
	ErrCodeConcurrentModificationException = "ConcurrentModificationException"

	// ErrCodeDeviceNotRegisteredException for service response error code
	// "DeviceNotRegisteredException".
	//
	// The request failed because this device is no longer registered and therefore
	// no longer managed by this account.
	ErrCodeDeviceNotRegisteredException = "DeviceNotRegisteredException"

	// ErrCodeInvalidCertificateAuthorityException for service response error code
	// "InvalidCertificateAuthorityException".
	//
	// The Certificate Authority can't issue or revoke a certificate.
	ErrCodeInvalidCertificateAuthorityException = "InvalidCertificateAuthorityException"

	// ErrCodeInvalidDeviceException for service response error code
	// "InvalidDeviceException".
	//
	// The device is in an invalid state.
	ErrCodeInvalidDeviceException = "InvalidDeviceException"

	// ErrCodeInvalidSecretsManagerResourceException for service response error code
	// "InvalidSecretsManagerResourceException".
	//
	// A password in SecretsManager is in an invalid state.
	ErrCodeInvalidSecretsManagerResourceException = "InvalidSecretsManagerResourceException"

	// ErrCodeInvalidServiceLinkedRoleStateException for service response error code
	// "InvalidServiceLinkedRoleStateException".
	//
	// The service linked role is locked for deletion.
	ErrCodeInvalidServiceLinkedRoleStateException = "InvalidServiceLinkedRoleStateException"

	// ErrCodeInvalidUserStatusException for service response error code
	// "InvalidUserStatusException".
	//
	// The attempt to update a user is invalid due to the user's current status.
	ErrCodeInvalidUserStatusException = "InvalidUserStatusException"

	// ErrCodeLimitExceededException for service response error code
	// "LimitExceededException".
	//
	// You are performing an action that would put you beyond your account's limits.
	ErrCodeLimitExceededException = "LimitExceededException"

	// ErrCodeNameInUseException for service response error code
	// "NameInUseException".
	//
	// The name sent in the request is already in use.
	ErrCodeNameInUseException = "NameInUseException"

	// ErrCodeNotFoundException for service response error code
	// "NotFoundException".
	//
	// The resource is not found.
	ErrCodeNotFoundException = "NotFoundException"

	// ErrCodeResourceAssociatedException for service response error code
	// "ResourceAssociatedException".
	//
	// Another resource is associated with the resource in the request.
	ErrCodeResourceAssociatedException = "ResourceAssociatedException"

	// ErrCodeResourceInUseException for service response error code
	// "ResourceInUseException".
	//
	// The resource in the request is already in use.
	ErrCodeResourceInUseException = "ResourceInUseException"

	// ErrCodeSkillNotLinkedException for service response error code
	// "SkillNotLinkedException".
	//
	// The skill must be linked to a third-party account.
	ErrCodeSkillNotLinkedException = "SkillNotLinkedException"

	// ErrCodeUnauthorizedException for service response error code
	// "UnauthorizedException".
	//
	// The caller has no permissions to operate on the resource involved in the
	// API call.
	ErrCodeUnauthorizedException = "UnauthorizedException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"AlreadyExistsException":                 newErrorAlreadyExistsException,
	"ConcurrentModificationException":        newErrorConcurrentModificationException,
	"DeviceNotRegisteredException":           newErrorDeviceNotRegisteredException,
	"InvalidCertificateAuthorityException":   newErrorInvalidCertificateAuthorityException,
	"InvalidDeviceException":                 newErrorInvalidDeviceException,
	"InvalidSecretsManagerResourceException": newErrorInvalidSecretsManagerResourceException,
	"InvalidServiceLinkedRoleStateException": newErrorInvalidServiceLinkedRoleStateException,
	"InvalidUserStatusException":             newErrorInvalidUserStatusException,
	"LimitExceededException":                 newErrorLimitExceededException,
	"NameInUseException":                     newErrorNameInUseException,
	"NotFoundException":                      newErrorNotFoundException,
	"ResourceAssociatedException":            newErrorResourceAssociatedException,
	"ResourceInUseException":                 newErrorResourceInUseException,
	"SkillNotLinkedException":                newErrorSkillNotLinkedException,
	"UnauthorizedException":                  newErrorUnauthorizedException,
}
