// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package appintegrationsservice

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeAccessDeniedException for service response error code
	// "AccessDeniedException".
	//
	// You do not have sufficient access to perform this action.
	ErrCodeAccessDeniedException = "AccessDeniedException"

	// ErrCodeDuplicateResourceException for service response error code
	// "DuplicateResourceException".
	//
	// A resource with the specified name already exists.
	ErrCodeDuplicateResourceException = "DuplicateResourceException"

	// ErrCodeInternalServiceError for service response error code
	// "InternalServiceError".
	//
	// Request processing failed due to an error or failure with the service.
	ErrCodeInternalServiceError = "InternalServiceError"

	// ErrCodeInvalidRequestException for service response error code
	// "InvalidRequestException".
	//
	// The request is not valid.
	ErrCodeInvalidRequestException = "InvalidRequestException"

	// ErrCodeResourceNotFoundException for service response error code
	// "ResourceNotFoundException".
	//
	// The specified resource was not found.
	ErrCodeResourceNotFoundException = "ResourceNotFoundException"

	// ErrCodeResourceQuotaExceededException for service response error code
	// "ResourceQuotaExceededException".
	//
	// The allowed quota for the resource has been exceeded.
	ErrCodeResourceQuotaExceededException = "ResourceQuotaExceededException"

	// ErrCodeThrottlingException for service response error code
	// "ThrottlingException".
	//
	// The throttling limit has been exceeded.
	ErrCodeThrottlingException = "ThrottlingException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"AccessDeniedException":          newErrorAccessDeniedException,
	"DuplicateResourceException":     newErrorDuplicateResourceException,
	"InternalServiceError":           newErrorInternalServiceError,
	"InvalidRequestException":        newErrorInvalidRequestException,
	"ResourceNotFoundException":      newErrorResourceNotFoundException,
	"ResourceQuotaExceededException": newErrorResourceQuotaExceededException,
	"ThrottlingException":            newErrorThrottlingException,
}
