// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package managedblockchain

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeAccessDeniedException for service response error code
	// "AccessDeniedException".
	//
	// You do not have sufficient access to perform this action.
	ErrCodeAccessDeniedException = "AccessDeniedException"

	// ErrCodeIllegalActionException for service response error code
	// "IllegalActionException".
	ErrCodeIllegalActionException = "IllegalActionException"

	// ErrCodeInternalServiceErrorException for service response error code
	// "InternalServiceErrorException".
	//
	// The request processing has failed because of an unknown error, exception
	// or failure.
	ErrCodeInternalServiceErrorException = "InternalServiceErrorException"

	// ErrCodeInvalidRequestException for service response error code
	// "InvalidRequestException".
	//
	// The action or operation requested is invalid. Verify that the action is typed
	// correctly.
	ErrCodeInvalidRequestException = "InvalidRequestException"

	// ErrCodeResourceAlreadyExistsException for service response error code
	// "ResourceAlreadyExistsException".
	//
	// A resource request is issued for a resource that already exists.
	ErrCodeResourceAlreadyExistsException = "ResourceAlreadyExistsException"

	// ErrCodeResourceLimitExceededException for service response error code
	// "ResourceLimitExceededException".
	//
	// The maximum number of resources of that type already exist. Ensure the resources
	// requested are within the boundaries of the service edition and your account
	// limits.
	ErrCodeResourceLimitExceededException = "ResourceLimitExceededException"

	// ErrCodeResourceNotFoundException for service response error code
	// "ResourceNotFoundException".
	//
	// A requested resource does not exist on the network. It may have been deleted
	// or referenced inaccurately.
	ErrCodeResourceNotFoundException = "ResourceNotFoundException"

	// ErrCodeResourceNotReadyException for service response error code
	// "ResourceNotReadyException".
	//
	// The requested resource exists but is not in a status that can complete the
	// operation.
	ErrCodeResourceNotReadyException = "ResourceNotReadyException"

	// ErrCodeThrottlingException for service response error code
	// "ThrottlingException".
	//
	// The request or operation could not be performed because a service is throttling
	// requests. The most common source of throttling errors is launching EC2 instances
	// such that your service limit for EC2 instances is exceeded. Request a limit
	// increase or delete unused resources if possible.
	ErrCodeThrottlingException = "ThrottlingException"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"AccessDeniedException":          newErrorAccessDeniedException,
	"IllegalActionException":         newErrorIllegalActionException,
	"InternalServiceErrorException":  newErrorInternalServiceErrorException,
	"InvalidRequestException":        newErrorInvalidRequestException,
	"ResourceAlreadyExistsException": newErrorResourceAlreadyExistsException,
	"ResourceLimitExceededException": newErrorResourceLimitExceededException,
	"ResourceNotFoundException":      newErrorResourceNotFoundException,
	"ResourceNotReadyException":      newErrorResourceNotReadyException,
	"ThrottlingException":            newErrorThrottlingException,
}
