// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package savingsplans provides the client and types for making API
// requests to AWS Savings Plans.
//
// Savings Plans are a pricing model that offer significant savings on AWS usage
// (for example, on Amazon EC2 instances). You commit to a consistent amount
// of usage, in USD per hour, for a term of 1 or 3 years, and receive a lower
// price for that usage. For more information, see the AWS Savings Plans User
// Guide (https://docs.aws.amazon.com/savingsplans/latest/userguide/).
//
// See https://docs.aws.amazon.com/goto/WebAPI/savingsplans-2019-06-28 for more information on this service.
//
// See savingsplans package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/savingsplans/
//
// Using the Client
//
// To contact AWS Savings Plans with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Savings Plans client SavingsPlans for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/savingsplans/#New
package savingsplans
