// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package marketplaceentitlementservice provides the client and types for making API
// requests to AWS Marketplace Entitlement Service.
//
// This reference provides descriptions of the AWS Marketplace Entitlement Service
// API.
//
// AWS Marketplace Entitlement Service is used to determine the entitlement
// of a customer to a given product. An entitlement represents capacity in a
// product owned by the customer. For example, a customer might own some number
// of users or seats in an SaaS application or some amount of data capacity
// in a multi-tenant database.
//
// Getting Entitlement Records
//
//    * GetEntitlements- Gets the entitlements for a Marketplace product.
//
// See https://docs.aws.amazon.com/goto/WebAPI/entitlement.marketplace-2017-01-11 for more information on this service.
//
// See marketplaceentitlementservice package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/marketplaceentitlementservice/
//
// Using the Client
//
// To contact AWS Marketplace Entitlement Service with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS Marketplace Entitlement Service client MarketplaceEntitlementService for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/marketplaceentitlementservice/#New
package marketplaceentitlementservice
