// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package timestreamwrite provides the client and types for making API
// requests to Amazon Timestream Write.
//
// Amazon Timestream is a fast, scalable, fully managed time series database
// service that makes it easy to store and analyze trillions of time series
// data points per day. With Timestream, you can easily store and analyze IoT
// sensor data to derive insights from your IoT applications. You can analyze
// industrial telemetry to streamline equipment management and maintenance.
// You can also store and analyze log data and metrics to improve the performance
// and availability of your applications. Timestream is built from the ground
// up to effectively ingest, process, and store time series data. It organizes
// data to optimize query processing. It automatically scales based on the volume
// of data ingested and on the query volume to ensure you receive optimal performance
// while inserting and querying data. As your data grows over time, Timestream’s
// adaptive query processing engine spans across storage tiers to provide fast
// analysis while reducing costs.
//
// See https://docs.aws.amazon.com/goto/WebAPI/timestream-write-2018-11-01 for more information on this service.
//
// See timestreamwrite package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/timestreamwrite/
//
// Using the Client
//
// To contact Amazon Timestream Write with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Timestream Write client TimestreamWrite for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/timestreamwrite/#New
package timestreamwrite
