// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package efs provides the client and types for making API
// requests to Amazon Elastic File System.
//
// Amazon Elastic File System (Amazon EFS) provides simple, scalable file storage
// for use with Amazon EC2 instances in the AWS Cloud. With Amazon EFS, storage
// capacity is elastic, growing and shrinking automatically as you add and remove
// files, so your applications have the storage they need, when they need it.
// For more information, see the User Guide (https://docs.aws.amazon.com/efs/latest/ug/api-reference.html).
//
// See https://docs.aws.amazon.com/goto/WebAPI/elasticfilesystem-2015-02-01 for more information on this service.
//
// See efs package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/efs/
//
// Using the Client
//
// To contact Amazon Elastic File System with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the Amazon Elastic File System client EFS for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/efs/#New
package efs
