// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

// Package rdsdataservice provides the client and types for making API
// requests to AWS RDS DataService.
//
// Amazon RDS provides an HTTP endpoint to run SQL statements on an Amazon Aurora
// Serverless DB cluster. To run these statements, you work with the Data Service
// API.
//
// For more information about the Data Service API, see Using the Data API for
// Aurora Serverless (https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/data-api.html)
// in the Amazon Aurora User Guide.
//
// If you have questions or comments related to the Data API, send email to
// Rds-data-api-feedback@amazon.com (mailto:Rds-data-api-feedback@amazon.com).
//
// See https://docs.aws.amazon.com/goto/WebAPI/rds-data-2018-08-01 for more information on this service.
//
// See rdsdataservice package documentation for more information.
// https://docs.aws.amazon.com/sdk-for-go/api/service/rdsdataservice/
//
// Using the Client
//
// To contact AWS RDS DataService with the SDK use the New function to create
// a new service client. With that client you can make API requests to the service.
// These clients are safe to use concurrently.
//
// See the SDK's documentation for more information on how to use the SDK.
// https://docs.aws.amazon.com/sdk-for-go/api/
//
// See aws.Config documentation for more information on configuring SDK clients.
// https://docs.aws.amazon.com/sdk-for-go/api/aws/#Config
//
// See the AWS RDS DataService client RDSDataService for more
// information on creating client for this service.
// https://docs.aws.amazon.com/sdk-for-go/api/service/rdsdataservice/#New
package rdsdataservice
