// Code generated by private/model/cli/gen-api/main.go. DO NOT EDIT.

package sfn

import (
	"github.com/aws/aws-sdk-go/private/protocol"
)

const (

	// ErrCodeActivityDoesNotExist for service response error code
	// "ActivityDoesNotExist".
	//
	// The specified activity does not exist.
	ErrCodeActivityDoesNotExist = "ActivityDoesNotExist"

	// ErrCodeActivityLimitExceeded for service response error code
	// "ActivityLimitExceeded".
	//
	// The maximum number of activities has been reached. Existing activities must
	// be deleted before a new activity can be created.
	ErrCodeActivityLimitExceeded = "ActivityLimitExceeded"

	// ErrCodeActivityWorkerLimitExceeded for service response error code
	// "ActivityWorkerLimitExceeded".
	//
	// The maximum number of workers concurrently polling for activity tasks has
	// been reached.
	ErrCodeActivityWorkerLimitExceeded = "ActivityWorkerLimitExceeded"

	// ErrCodeExecutionAlreadyExists for service response error code
	// "ExecutionAlreadyExists".
	//
	// The execution has the same name as another execution (but a different input).
	//
	// Executions with the same name and input are considered idempotent.
	ErrCodeExecutionAlreadyExists = "ExecutionAlreadyExists"

	// ErrCodeExecutionDoesNotExist for service response error code
	// "ExecutionDoesNotExist".
	//
	// The specified execution does not exist.
	ErrCodeExecutionDoesNotExist = "ExecutionDoesNotExist"

	// ErrCodeExecutionLimitExceeded for service response error code
	// "ExecutionLimitExceeded".
	//
	// The maximum number of running executions has been reached. Running executions
	// must end or be stopped before a new execution can be started.
	ErrCodeExecutionLimitExceeded = "ExecutionLimitExceeded"

	// ErrCodeInvalidArn for service response error code
	// "InvalidArn".
	//
	// The provided Amazon Resource Name (ARN) is invalid.
	ErrCodeInvalidArn = "InvalidArn"

	// ErrCodeInvalidDefinition for service response error code
	// "InvalidDefinition".
	//
	// The provided Amazon States Language definition is invalid.
	ErrCodeInvalidDefinition = "InvalidDefinition"

	// ErrCodeInvalidExecutionInput for service response error code
	// "InvalidExecutionInput".
	//
	// The provided JSON input data is invalid.
	ErrCodeInvalidExecutionInput = "InvalidExecutionInput"

	// ErrCodeInvalidLoggingConfiguration for service response error code
	// "InvalidLoggingConfiguration".
	ErrCodeInvalidLoggingConfiguration = "InvalidLoggingConfiguration"

	// ErrCodeInvalidName for service response error code
	// "InvalidName".
	//
	// The provided name is invalid.
	ErrCodeInvalidName = "InvalidName"

	// ErrCodeInvalidOutput for service response error code
	// "InvalidOutput".
	//
	// The provided JSON output data is invalid.
	ErrCodeInvalidOutput = "InvalidOutput"

	// ErrCodeInvalidToken for service response error code
	// "InvalidToken".
	//
	// The provided token is invalid.
	ErrCodeInvalidToken = "InvalidToken"

	// ErrCodeInvalidTracingConfiguration for service response error code
	// "InvalidTracingConfiguration".
	//
	// Your tracingConfiguration key does not match, or enabled has not been set
	// to true or false.
	ErrCodeInvalidTracingConfiguration = "InvalidTracingConfiguration"

	// ErrCodeMissingRequiredParameter for service response error code
	// "MissingRequiredParameter".
	//
	// Request is missing a required parameter. This error occurs if both definition
	// and roleArn are not specified.
	ErrCodeMissingRequiredParameter = "MissingRequiredParameter"

	// ErrCodeResourceNotFound for service response error code
	// "ResourceNotFound".
	//
	// Could not find the referenced resource. Only state machine and activity ARNs
	// are supported.
	ErrCodeResourceNotFound = "ResourceNotFound"

	// ErrCodeStateMachineAlreadyExists for service response error code
	// "StateMachineAlreadyExists".
	//
	// A state machine with the same name but a different definition or role ARN
	// already exists.
	ErrCodeStateMachineAlreadyExists = "StateMachineAlreadyExists"

	// ErrCodeStateMachineDeleting for service response error code
	// "StateMachineDeleting".
	//
	// The specified state machine is being deleted.
	ErrCodeStateMachineDeleting = "StateMachineDeleting"

	// ErrCodeStateMachineDoesNotExist for service response error code
	// "StateMachineDoesNotExist".
	//
	// The specified state machine does not exist.
	ErrCodeStateMachineDoesNotExist = "StateMachineDoesNotExist"

	// ErrCodeStateMachineLimitExceeded for service response error code
	// "StateMachineLimitExceeded".
	//
	// The maximum number of state machines has been reached. Existing state machines
	// must be deleted before a new state machine can be created.
	ErrCodeStateMachineLimitExceeded = "StateMachineLimitExceeded"

	// ErrCodeStateMachineTypeNotSupported for service response error code
	// "StateMachineTypeNotSupported".
	ErrCodeStateMachineTypeNotSupported = "StateMachineTypeNotSupported"

	// ErrCodeTaskDoesNotExist for service response error code
	// "TaskDoesNotExist".
	ErrCodeTaskDoesNotExist = "TaskDoesNotExist"

	// ErrCodeTaskTimedOut for service response error code
	// "TaskTimedOut".
	ErrCodeTaskTimedOut = "TaskTimedOut"

	// ErrCodeTooManyTags for service response error code
	// "TooManyTags".
	//
	// You've exceeded the number of tags allowed for a resource. See the Limits
	// Topic (https://docs.aws.amazon.com/step-functions/latest/dg/limits.html)
	// in the AWS Step Functions Developer Guide.
	ErrCodeTooManyTags = "TooManyTags"
)

var exceptionFromCode = map[string]func(protocol.ResponseMetadata) error{
	"ActivityDoesNotExist":         newErrorActivityDoesNotExist,
	"ActivityLimitExceeded":        newErrorActivityLimitExceeded,
	"ActivityWorkerLimitExceeded":  newErrorActivityWorkerLimitExceeded,
	"ExecutionAlreadyExists":       newErrorExecutionAlreadyExists,
	"ExecutionDoesNotExist":        newErrorExecutionDoesNotExist,
	"ExecutionLimitExceeded":       newErrorExecutionLimitExceeded,
	"InvalidArn":                   newErrorInvalidArn,
	"InvalidDefinition":            newErrorInvalidDefinition,
	"InvalidExecutionInput":        newErrorInvalidExecutionInput,
	"InvalidLoggingConfiguration":  newErrorInvalidLoggingConfiguration,
	"InvalidName":                  newErrorInvalidName,
	"InvalidOutput":                newErrorInvalidOutput,
	"InvalidToken":                 newErrorInvalidToken,
	"InvalidTracingConfiguration":  newErrorInvalidTracingConfiguration,
	"MissingRequiredParameter":     newErrorMissingRequiredParameter,
	"ResourceNotFound":             newErrorResourceNotFound,
	"StateMachineAlreadyExists":    newErrorStateMachineAlreadyExists,
	"StateMachineDeleting":         newErrorStateMachineDeleting,
	"StateMachineDoesNotExist":     newErrorStateMachineDoesNotExist,
	"StateMachineLimitExceeded":    newErrorStateMachineLimitExceeded,
	"StateMachineTypeNotSupported": newErrorStateMachineTypeNotSupported,
	"TaskDoesNotExist":             newErrorTaskDoesNotExist,
	"TaskTimedOut":                 newErrorTaskTimedOut,
	"TooManyTags":                  newErrorTooManyTags,
}
